package com.jiuqi.util.comparator;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

public final class AggreatedComparator implements Comparator {
   private List comparators = new ArrayList();

   public int compare(Object o1, Object o2) {
      if (o1 == o2) {
         return 0;
      } else if (o1 == null) {
         return -1;
      } else if (o2 == null) {
         return 1;
      } else {
         Object[] arr1 = (Object[])o1;
         Object[] arr2 = (Object[])o2;
         int len = Math.min(Math.min(arr1.length, arr2.length), this.comparators.size());

         for(int i = 0; i < len; ++i) {
            Comparator c = (Comparator)this.comparators.get(i);
            int ret = c.compare(arr1[i], arr2[i]);
            if (ret != 0) {
               return ret;
            }
         }

         return 0;
      }
   }

   public boolean equals(Object obj) {
      if (this == obj) {
         return true;
      } else if (this != null && obj != null) {
         if (!(obj instanceof AggreatedComparator)) {
            return false;
         } else {
            AggreatedComparator cmp = (AggreatedComparator)obj;
            if (this.comparators.size() != cmp.comparators.size()) {
               return false;
            } else {
               for(int i = 0; i < this.comparators.size(); ++i) {
                  if (!this.comparators.get(i).equals(cmp.comparators.get(i))) {
                     return false;
                  }
               }

               return true;
            }
         }
      } else {
         return false;
      }
   }

   public String toString() {
      StringBuffer result = new StringBuffer("[聚合比较器");

      for(int i = 0; i < this.comparators.size(); ++i) {
         result.append(", ");
         result.append(this.comparators.get(i));
      }

      result.append("]");
      return result.toString();
   }

   public void addComparator(Comparator comparator) {
      this.comparators.add(comparator);
   }

   public void removeComparator(Comparator comparator) {
      this.comparators.remove(comparator);
   }

   public Comparator[] getAllComparators() {
      return (Comparator[])this.comparators.toArray(new Comparator[0]);
   }
}
